summaryrefslogtreecommitdiffstats
path: root/kmail/kmfilterdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfilterdlg.cpp')
-rw-r--r--kmail/kmfilterdlg.cpp60
1 files changed, 30 insertions, 30 deletions
diff --git a/kmail/kmfilterdlg.cpp b/kmail/kmfilterdlg.cpp
index c9e42d1c..a83b6eec 100644
--- a/kmail/kmfilterdlg.cpp
+++ b/kmail/kmfilterdlg.cpp
@@ -32,7 +32,7 @@ using KMail::FilterImporterExporter;
#include <klistview.h>
#include <kpushbutton.h>
// other Qt headers:
#include <tqlayout.h>
#include <tqlabel.h>
#include <tqcombobox.h>
@@ -128,8 +128,8 @@ const char * KMPopFilterDlgHelpAnchor = "popfilters-id" ;
//
//=============================================================================
-KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, bool createDummyFilter )
- : KDialogBase( parent, name, false /* modality */,
+KMFilterDlg::KMFilterDlg(TQWidget* tqparent, const char* name, bool popFilter, bool createDummyFilter )
+ : KDialogBase( tqparent, name, false /* modality */,
(popFilter)? i18n("POP3 Filter Rules"): i18n("Filter Rules") /* caption*/,
Help|Ok|Apply|Cancel|User1|User2 /* button tqmask */,
Ok /* default btn */, false /* separator */),
@@ -173,21 +173,21 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
hbl->setStretchFactor( vbl, 2 );
mPatternEdit = new KMSearchPatternEdit( i18n("Filter Criteria"), bPopFilter ? w : page1 , "spe", bPopFilter);
- vbl->addWidget( mPatternEdit, 0, Qt::AlignTop );
+ vbl->addWidget( mPatternEdit, 0, TQt::AlignTop );
if(bPopFilter){
mActionGroup = new KMPopFilterActionWidget( i18n("Filter Action"), w );
- vbl->addWidget( mActionGroup, 0, Qt::AlignTop );
+ vbl->addWidget( mActionGroup, 0, TQt::AlignTop );
mGlobalsBox = new TQVGroupBox(i18n("Global Options"), w);
mShowLaterBtn = new TQCheckBox(i18n("Always &show matched 'Download Later' messages in confirmation dialog"), mGlobalsBox);
TQWhatsThis::add( mShowLaterBtn, i18n(_wt_filterdlg_showLater) );
- vbl->addWidget( mGlobalsBox, 0, Qt::AlignTop );
+ vbl->addWidget( mGlobalsBox, 0, TQt::AlignTop );
}
else {
TQGroupBox *agb = new TQGroupBox( 1 /*column*/, Vertical, i18n("Filter Actions"), page1 );
mActionLister = new KMFilterActionWidgetLister( agb );
- vbl->addWidget( agb, 0, Qt::AlignTop );
+ vbl->addWidget( agb, 0, TQt::AlignTop );
mAdvOptsGroup = new TQGroupBox ( 1 /*columns*/, Vertical,
i18n("Advanced Options"), page2);
@@ -257,7 +257,7 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
gl->addMultiCellWidget( hbox, 9, 9, 0, 3 );
}
- vbl2->addWidget( mAdvOptsGroup, 0, Qt::AlignTop );
+ vbl2->addWidget( mAdvOptsGroup, 0, TQt::AlignTop );
}
// spacer:
vbl->addStretch( 1 );
@@ -577,8 +577,8 @@ void KMFilterDlg::slotUpdateAccountList()
//
//=============================================================================
-KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *parent, const char* name, bool popFilter )
- : TQGroupBox( 1, Horizontal, title, parent, name ),
+KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *tqparent, const char* name, bool popFilter )
+ : TQGroupBox( 1, Horizontal, title, tqparent, name ),
bPopFilter(popFilter)
{
mFilterList.setAutoDelete( true );
@@ -592,19 +592,19 @@ KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *parent, cons
//----------- the first row of buttons
TQHBox *hb = new TQHBox(this);
hb->setSpacing(4);
- mBtnTop = new KPushButton( TQString::null, hb );
+ mBtnTop = new KPushButton( TQString(), hb );
mBtnTop->setAutoRepeat( true );
mBtnTop->setIconSet( BarIconSet( "top", KIcon::SizeSmall ) );
mBtnTop->setMinimumSize( mBtnTop->tqsizeHint() * 1.2 );
- mBtnUp = new KPushButton( TQString::null, hb );
+ mBtnUp = new KPushButton( TQString(), hb );
mBtnUp->setAutoRepeat( true );
mBtnUp->setIconSet( BarIconSet( "up", KIcon::SizeSmall ) );
mBtnUp->setMinimumSize( mBtnUp->tqsizeHint() * 1.2 );
- mBtnDown = new KPushButton( TQString::null, hb );
+ mBtnDown = new KPushButton( TQString(), hb );
mBtnDown->setAutoRepeat( true );
mBtnDown->setIconSet( BarIconSet( "down", KIcon::SizeSmall ) );
mBtnDown->setMinimumSize( mBtnDown->tqsizeHint() * 1.2 );
- mBtnBot = new KPushButton( TQString::null, hb );
+ mBtnBot = new KPushButton( TQString(), hb );
mBtnBot->setAutoRepeat( true );
mBtnBot->setIconSet( BarIconSet( "bottom", KIcon::SizeSmall ) );
mBtnBot->setMinimumSize( mBtnBot->tqsizeHint() * 1.2 );
@@ -620,13 +620,13 @@ KMFilterListBox::KMFilterListBox( const TQString & title, TQWidget *parent, cons
//----------- the second row of buttons
hb = new TQHBox(this);
hb->setSpacing(4);
- mBtnNew = new TQPushButton( TQString::null, hb );
+ mBtnNew = new TQPushButton( TQString(), hb );
mBtnNew->setPixmap( BarIcon( "filenew", KIcon::SizeSmall ) );
mBtnNew->setMinimumSize( mBtnNew->tqsizeHint() * 1.2 );
- mBtnCopy = new TQPushButton( TQString::null, hb );
+ mBtnCopy = new TQPushButton( TQString(), hb );
mBtnCopy->setIconSet( BarIconSet( "editcopy", KIcon::SizeSmall ) );
mBtnCopy->setMinimumSize( mBtnCopy->tqsizeHint() * 1.2 );
- mBtnDelete = new TQPushButton( TQString::null, hb );
+ mBtnDelete = new TQPushButton( TQString(), hb );
mBtnDelete->setIconSet( BarIconSet( "editdelete", KIcon::SizeSmall ) );
mBtnDelete->setMinimumSize( mBtnDelete->tqsizeHint() * 1.2 );
mBtnRename = new TQPushButton( i18n("Rename..."), hb );
@@ -757,7 +757,7 @@ void KMFilterListBox::slotApplyFilterChanges()
"IMAP account. Such filters will only be applied "
"when manually filtering and when filtering "
"incoming online IMAP mail.");
- KMessageBox::information( this, str, TQString::null,
+ KMessageBox::information( this, str, TQString(),
"filterDlgOnlineImapCheck" );
}
}
@@ -786,7 +786,7 @@ TQValueList<KMFilter*> KMFilterListBox::filtersForSaving() const
TQString msg = i18n("The following filters have not been saved because they "
"were invalid (e.g. containing no actions or no search "
"rules).");
- KMessageBox::informationList( 0, msg, emptyFilters, TQString::null,
+ KMessageBox::informationList( 0, msg, emptyFilters, TQString(),
"ShowInvalidFilterWarning" );
}
return filters;
@@ -1108,8 +1108,8 @@ void KMFilterListBox::swapFilters( int from, int to )
//
//=============================================================================
-KMFilterActionWidget::KMFilterActionWidget( TQWidget *parent, const char* name )
- : TQHBox( parent, name )
+KMFilterActionWidget::KMFilterActionWidget( TQWidget *tqparent, const char* name )
+ : TQHBox( tqparent, name )
{
int i;
mActionList.setAutoDelete( true );
@@ -1162,7 +1162,7 @@ void KMFilterActionWidget::setAction( const KMFilterAction* aAction )
int i=0;
bool found = false ;
int count = mComboBox->count() - 1 ; // last entry is the empty one
- TQString label = ( aAction ) ? aAction->label() : TQString::null ;
+ TQString label = ( aAction ) ? aAction->label() : TQString() ;
// find the index of typeOf(aAction) in mComboBox
// and clear the other widgets on the way.
@@ -1209,8 +1209,8 @@ KMFilterAction * KMFilterActionWidget::action()
//
//=============================================================================
-KMFilterActionWidgetLister::KMFilterActionWidgetLister( TQWidget *parent, const char* name )
- : KWidgetLister( 1, FILTER_MAX_ACTIONS, parent, name )
+KMFilterActionWidgetLister::KMFilterActionWidgetLister( TQWidget *tqparent, const char* name )
+ : KWidgetLister( 1, FILTER_MAX_ACTIONS, tqparent, name )
{
mActionList = 0;
}
@@ -1228,7 +1228,7 @@ void KMFilterActionWidgetLister::setActionList( TQPtrList<KMFilterAction> *aList
mActionList = aList;
- ((TQWidget*)parent())->setEnabled( true );
+ ((TQWidget*)tqparent())->setEnabled( true );
if ( aList->count() == 0 ) {
slotClear();
@@ -1262,12 +1262,12 @@ void KMFilterActionWidgetLister::reset()
mActionList = 0;
slotClear();
- ((TQWidget*)parent())->setEnabled( false );
+ ((TQWidget*)tqparent())->setEnabled( false );
}
-TQWidget* KMFilterActionWidgetLister::createWidget( TQWidget *parent )
+TQWidget* KMFilterActionWidgetLister::createWidget( TQWidget *tqparent )
{
- return new KMFilterActionWidget(parent);
+ return new KMFilterActionWidget(tqparent);
}
void KMFilterActionWidgetLister::clearWidget( TQWidget *aWidget )
@@ -1297,8 +1297,8 @@ void KMFilterActionWidgetLister::regenerateActionListFromWidgets()
//
//=============================================================================
-KMPopFilterActionWidget::KMPopFilterActionWidget( const TQString& title, TQWidget *parent, const char* name )
- : TQVButtonGroup( title, parent, name )
+KMPopFilterActionWidget::KMPopFilterActionWidget( const TQString& title, TQWidget *tqparent, const char* name )
+ : TQVButtonGroup( title, tqparent, name )
{
mActionMap[Down] = new TQRadioButton( i18n("&Download mail"), this );
mActionMap[Later] = new TQRadioButton( i18n("Download mail la&ter"), this );
@@ -32,7 +32,7 @@ using KMail::FilterImporterExporter;
#include <klistview.h>
#include <kpushbutton.h>
-// other Qt headers:
+// other TQt headers:
#include <tqlayout.h>
#include <tqlabel.h>